/*
 *    TODO.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.classification;

// java standard library classes used
import java.io.Serializable;
import java.lang.Cloneable;
import java.util.Enumeration;

/**
 * An abstract Collections Policy 
 *
 * Assigns documents into levels of priority base on their 
 * Classification metadata. The levels range from 0, indicating that
 * a document is no relavent in a collection, to 5, indicating that 
 * the library will make all reasonably possible actions to obtain
 * a document for this collection.
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2191 $
 * @see DeweyDecimalCollectionsPolicy
 * @see Classification
 * @see ClassificationSystem
 */

public interface CollectionsPolicy extends Cloneable, Serializable
{
  /**
   * Get the ClassificationSystem used by the CollectionsPolicy
   * 
   * @return ClassificationSystem
   * @see ClassificationSystem
   */  
  ClassificationSystem getClassificationSystem();
  /**
   * Assign a level to a piece of metadata. 
   *
   * The metadata must be in a format understood by the 
   * ClassificationSystem used by the CollectionsPolicy
   * 
   * @exception java.io.IOException when ...
   * @param metadata the metadata
   * @return the level
   * @see ClassificationSystem
   */
   int level(String metadata);

  /**
   * Assign a level to a collection of metadata. 
   *
   * The metadata must be in a format understood by the 
   * ClassificationSystem used by the CollectionsPolicy
   * 
   * @exception java.io.IOException when ...
   * @param metadata the metadata
   * @return the level
   * @see ClassificationSystem
   */
  int level(String[] metadata);
  
  /**
   * Get all Classifications for a given level
   * 
   * @exception java.io.IOException when ...
   * @param level the level for which Classifications are returned
   * @return the Classifications
   * @see Classification
   */
  Enumeration getClassificationsForLevel(int level);
}

